@@ -1,46 +1,40 @@
 ######################################################################
 # HTTP.pm - This is PyukiWiki, yet another Wiki clone.
-# $Id: HTTP.pm,v 1.23 2007/07/15 07:40:09 papu Exp $
+# $Id: HTTP.pm,v 1.306 2011/12/31 13:06:10 papu Exp $
 #
-# "Nana::HTTP" version 0.2 $$
+# "Nana::HTTP" version 0.6 $$
 # Author: Nanami
-# http://lineage.netgamers.jp/
-# Copyright (C) 2004-2007 by Nekyo.
-# http://nekyo.hp.infoseek.co.jp/
-# Copyright (C) 2005-2007 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# http://nanakochi.daiba.cx/
+# Copyright (C) 2004-2012 by Nekyo.
+# http://nekyo.qp.land.to/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
 # License: GPL2 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 # Return:LF Code=EUC-JP 1TAB=4Spaces
 ######################################################################
-
 package	Nana::HTTP;
 use 5.005;
 use strict;
+use strict;
+use Socket 1.3;
+use Fcntl;
+use Errno qw(EAGAIN);
+use HTTP::Lite;
 use vars qw($VERSION);
-$VERSION = '0.2';
-
-# 0:°󥸥 1:LWP¸ߤLWPʤ°󥸥
+$VERSION = '0.6';
+# 0:°󥸥(HTTP::Lite) 1:LWP¸ߤLWPʤ°󥸥
 $Nana::HTTP::useLWP=0;
-
 # 桼
 $Nana::HTTP::UserAgent="$::package/$::version \@\@";
-
 # ॢ
-$Nana::HTTP::timeout=20;
-
-# ƻԲ (ǳǡLWP̤)
-$Nana::HTTP::counter=2;
-
+$Nana::HTTP::timeout=2;
 ######################################################################
-
 my $timeoutflag=0;
-use Socket;
-
 sub new {
 	my ($class, %hash) = @_;
 	my $self = {
@@ -53,14 +47,16 @@ sub new {
 	};
 	$$self{lwp_ok}=0;
 	if($Nana::HTTP::useLWP eq 1) {
-		if(&load_module("LWP::UserAgent")) {
+		if(&load_module("LWP::UserAgent") && &load_module("HTTP::HEADERS")) {
 			$$self{lwp_ua}=LWP::UserAgent->new;
 			$$self{_ua} = &makeua($$self{lwp_ua}->_agent,%hash),
 			$$self{_header} = "User-Agent: " . $$self{_ua} . $$self{header};
 			$$self{lwp_ua}->agent($$self{_ua});
 			$$self{lwp_ua}->timeout($Nana::HTTP::timeout);
-			foreach("http", "https", "ftp") {
-				$$self{lwp_ua}->proxy($_,"http://$::proxy_host:$::proxy_port/")
+			if($::proxy_host ne '') {
+				foreach("http", "https", "ftp") {
+					$$self{lwp_ua}->proxy($_,"http://$::proxy_host:$::proxy_port/")
+				}
 			}
 			$$self{lwp_ok}=1;
 		}
@@ -72,12 +68,30 @@ sub new {
 	}
 	return bless $self, $class;
 }
-
 sub load_module {
 	my $funcp = $::functions{"load_module"};
 	return &$funcp(@_);
 }
-
+sub head {
+	my($self, $uri)=@_;
+	if($$self{lwp_ok} eq 1) {
+		my $req;
+		if($$self{user} . $$self{pass} ne '') {
+			my $header=HTTP::Headers->new;
+			$header->authorization_basic($$self{user},$$self{pass});
+			$req=HTTP::Request->new(HEAD => $uri, $header);
+		} else {
+			$req=HTTP::Request->new(HEAD => $uri);
+		}
+		my $res=$$self{lwp_ua}->request($req);
+		if($res->is_success) {
+			return(0,$res->content);
+		} else {
+			return(1,$res->status_line);
+		}
+	}
+	return &httpcl($uri,"HEAD", $$self{_header});
+}
 sub get {
 	my($self, $uri)=@_;
 	if($$self{lwp_ok} eq 1) {
@@ -98,10 +112,8 @@ sub get {
 	}
 	return &httpcl($uri,"GET", $$self{_header});
 }
-
 sub post {
 	my($self, $uri, $postdata)=@_;
-
 	if($$self{lwp_ok} eq 1) {
 		my $header;
 		my $req;
@@ -112,7 +124,6 @@ sub post {
 		$req=HTTP::Request->new(POST => $uri, $header);
 		$req->content_type('application/x-www-form-urlencoded');
 		$req->content($postdata);
-
 		my $res=$$self{lwp_ua}->request($req);
 		if($res->is_success) {
 			return(0,$res->content);
@@ -122,7 +133,6 @@ sub post {
 	}
 	return &httpcl($uri,"POST", $$self{_header}, $postdata);
 }
-
 sub makeua {
 	my($add,%self)=@_;
 	my $ua;
@@ -138,88 +148,30 @@ sub makeua {
 	} else {
 		$ua=$self{ua};
 	}
-	return $ua;
+	return "$::package/$::version ($::basehref $ua)";
 }
-
 sub httpcl {
 	my($url,$method,$header,$postdata)=@_;
-	my($stat,$ret);
-	my $timeoutcounter=$Nana::HTTP::counter;
-
-	$SIG{ALRM}=\&httpcl_timeout;
-	$ret="";
-
-	while($timeoutcounter>0) {
-		$timeoutflag=0;
-		alarm($Nana::HTTP::alarmtime / $Nana::HTTP::counter);
-		($stat,$ret)=&httpclsub($url,$method,$header,$postdata);
-		alarm(0);
-		$timeoutcounter--;
-		$ret="" if($timeoutflag eq 1);
-		if($ret eq '') {
-			$timeoutcounter=0;
-			$stat=5;
-		}
+	my $http=new HTTP::Lite;
+	$method="GET" if($method eq '');
+	$http->method($method);
+	$http->http11_mode(1);
+	foreach(split(/\n/,$header)) {
+		my($hn,$hv)=split(/:\s/,$_);
+		$http->add_req_header($hn,$hv) if($_=~/:/);
 	}
-	if($stat ne 0) {
-		$ret=("","Host not found","Can't Create Socket address"
-			, "Socket Error", "Can't connect Server", "Timeout")[$stat];
+	if($::proxy_host ne '' && $::proxy_port > 0) {
+		$http->proxy("http://$::proxy_host:$::proxy_port");
 	}
-	return ($stat,$ret);
-}
-
-sub httpclsub {
-	my($url,$method,$header,$postdata)=@_;
-	my($ret);
-	my($postlength);
-	my($iaddr,$sock_addr);
-	$ret="";
-	if(uc $method=~/^(GET|POST|HEAD)$/) {
-		if($url =~ m!(http:)?(//)?([^:/]*)?(:([0-9]+)?)?(/.*)?!) {
-			my $host = ($3 ne "") ? $3 : "localhost";
-			my $port = ($5 ne "") ? $5 : 80;
-			my $path = ($6 ne "") ? $6 : "/";
-			if($::proxy_host ne '' && $::proxy_port > 0) {
-				$iaddr = inet_aton($::proxy_host) || return (1,"");
-				$sock_addr = pack_sockaddr_in($::proxy_port, $iaddr) || return (2,"");
-				socket(SOCKET, PF_INET, SOCK_STREAM, 0) || return (3,"");
-				connect(SOCKET, $sock_addr) || return (4,"");
-				select(SOCKET); $|=1; select(STDOUT);
-				print SOCKET "$method $url HTTP/1.0\r\n";
-			} else {
-				$iaddr = inet_aton($host) || return (1,"");
-				$sock_addr = pack_sockaddr_in($port, $iaddr) || return (2,"");
-				socket(SOCKET, PF_INET, SOCK_STREAM, 0) || return (3,"");
-				connect(SOCKET, $sock_addr) || return (4,"");
-				select(SOCKET); $|=1; select(STDOUT);
-				print SOCKET "$method /$path HTTP/1.0\r\n";
-				print SOCKET "Host: $host:$port\r\n";
-			}
-			$postlength=length($postdata);
-			foreach(split(/\n/,$header)) {
-				print SOCKET "$_\r\n"
-					if($_=~/:/);
-			}
-			print SOCKET "Content-Length: $postlength\r\n" if($method eq 'POST');
-			print SOCKET "\r\n";
-			print SOCKET $postdata if($method eq 'POST');
-			print SOCKET "\r\n" if($method eq 'POST');
-			if($method ne 'HEAD') {	
-				while(<SOCKET>) {
-					m/^\r\n$/ && last;
-				}
-			}
-			while(<SOCKET>) {
-				s/\r//g;
-				$ret.=$_;
-			}
-		}
+	if($postdata ne '') {
+		$http->prepare_post($postdata);
+	}
+	my $req=$http->request($url);
+	if($req eq 200) {
+		return(0,$http->body());
+	} else {
+		return(1,"Error $req");
 	}
-	return (0,$ret);
 }
-sub httpcl_timeout {
-	$timeoutflag=1;
-}
-
 1;
 __END__
