@@ -1,21 +1,24 @@
 ######################################################################
 # ls2.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: ls2.inc.pl,v 1.92 2011/05/04 07:26:50 papu Exp $
+# $Id: ls2.inc.pl,v 1.505 2012/03/18 11:23:51 papu Exp $
 #
-# "PyukiWiki" version 0.1.9 $$
-# Author: Nekyo
-# Copyright (C) 2004-2011 by Nekyo.
+# "PyukiWiki" ver 0.2.0-p3 $$
+# Author: Nekyo http://nekyo.qp.land.to/
+# Copyright (C) 2004-2012 Nekyo
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2011 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 # Return:LF Code=EUC-JP 1TAB=4Spaces
 ######################################################################
+# v0.2.0-p3
+#        2012/03/13 Х
+# v0.2.0 2012/02/15 ƳؤɽǽMenuBarɽǽ
 # v0.1.6 2006/01/07 *****ޤб롢¾
 # v0.1   2005/04/01 encode Х Fix Tnx:Junichi
 # v0.0   2004/11/01 ʰ title,reverse б¾б
@@ -33,11 +36,10 @@
 #-include:󥯥롼ɤƤڡθФƵŪ󤹤
 #-link:actionץ饰ƤӽФ󥯤ɽ
 #-reverse:ڡ¤ӽȿž߽ˤ
+#-noprefix:Ƴؤɽʤ
 #-compact:
 ######################################################################
-
 use strict;
-
 sub plugin_ls2_convert
 {
 	my $prefix = '';
@@ -46,7 +48,7 @@ sub plugin_ls2_convert
 	my $reverse = 0;
 	my (@pages, $txt, @txt, $tocnum);
 	my $body = '';
-
+	my $noprefix = 0;
 	if (@args > 0) {
 		$prefix = shift(@args);
 		foreach my $arg (@args) {
@@ -54,18 +56,28 @@ sub plugin_ls2_convert
 				$title = 1;
 			} elsif (lc $arg eq "reverse") {
 				$reverse = 1;
+			} elsif (lc $arg eq "noprefix") {
+				$noprefix = 1;
 			}
 		}
 	}
-	$prefix = $::form{mypage} . "/" if ($prefix eq '');
-
+	$prefix = $::form{mypage} if ($prefix eq '');
 	foreach my $page (sort keys %::database) {
-		push(@pages, $page) if ($page =~ /^$prefix/ && &is_readable($page) && $page!~/$::non_list/);
+		if ($page =~ /^$prefix/ && &is_readable($page) && $page!~/$::non_list/) {
+			if($noprefix eq 1) {
+				my $cutedpage=$page;
+				$cutedpage=~s@^$prefix/@@g;
+				push(@pages, "$page\t$cutedpage")
+			} else {
+				push(@pages, "$page\t$page")
+			}
+		}
 	}
 	@pages = reverse(@pages) if ($reverse);
-	foreach my $page (@pages) {
+	foreach (@pages) {
+		my ($page, $cutedpage)=split(/\t/,$_);
 		$body .= <<"EOD";
-<li><a id ="list_1" href="@{[&make_cookedurl(&encode($page))]}" title="$page">$page</a></li>
+<li><a id ="list_1" href="@{[&make_cookedurl(&encode($page))]}" title="$page">$cutedpage</a></li>
 EOD
 		if ($title) {
 			$txt = $::database{$page};
@@ -76,7 +88,7 @@ EOD
 				chomp;
 				if (/^(\*{1,5})(.+)/) {
 					&back_push('ul', length($1), \@tocsaved, \@tocresult);
-					push(@tocresult, qq( <li><a href="@{[&make_cookedurl(&encode($page))]}#@{[&pageanchorname($page)]}$tocnum">@{[&escape($2)]}</a></li>\n));	
+					push(@tocresult, qq( <li><a href="@{[&make_cookedurl(&encode($page))]}#@{[&pageanchorname($page)]}$tocnum">@{[&escape($2)]}</a></li>\n));
 					$tocnum++;
 				}
 			}
@@ -86,11 +98,10 @@ EOD
 	}
 	if ($body ne '') {
 		return << "EOD";
-<ul class="list1" style="padding-left:16px;margin-left:16px">$body</ul>
+<ul class="list1">$body</ul>
 EOD
 	}
 	return "<strong>'$prefix'</strong> $::resource{ls2_plugin_notpage}<br />\n";
 }
-
 1;
 __END__
