@@ -1,16 +1,16 @@
 ######################################################################
 # sitemap.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: sitemap.inc.pl,v 1.59 2007/07/15 07:40:09 papu Exp $
+# $Id: sitemap.inc.pl,v 1.505 2012/03/18 11:23:51 papu Exp $
 #
-# "PyukiWiki" version 0.1.7 $$
-# Author: Nanami http://lineage.netgamers.jp/
-# Copyright (C) 2004-2007 by Nekyo.
-# http://nekyo.hp.infoseek.co.jp/
-# Copyright (C) 2005-2007 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# "PyukiWiki" ver 0.2.0-p3 $$
+# Author: Nanami http://nanakochi.daiba.cx/
+# Copyright (C) 2004-2012 Nekyo
+# http://nekyo.qp.land.to/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
@@ -38,22 +38,17 @@
 #
 # Ȥ
 # ?cmd=sitemap
-# http://lineage.netgamers.jp/?cmd=sitemap
+# /?cmd=sitemap
 #
-# ܤwikiΥߤƤ
-# http://lineage.netgamers.jp/?cmd=adminedit&mypage=MenuBar
-# http://lineage.netgamers.jp/?cmd=adminedit&mypage=%bd%d0%b2%d4%a4%ae%a5%ea%a5%b9%a5%c8
-# http://lineage.netgamers.jp/?cmd=edit&mypage=%bd%d0%b2%d4%a4%aeFPK%b9%b6%ce%ac
 ######################################################################
-
 sub plugin_sitemap_convert {
 	$::form{title}='no';
+#	$::form{ls2}='no';
 	$::form{level}=2;
 	$::form{subject}=1;
 	my %sitemap=&plugin_sitemap_action;
 	return $sitemap{body};
 }
-
 sub plugin_sitemap_action {
 	my $prev = '';
 	my $char = '';
@@ -67,16 +62,13 @@ sub plugin_sitemap_action {
 	my $body="<h2>@{[$::wiki_title eq '' ? $::resource{sitemap_plugin_title} : $::wiki_title]}</h2>\n"
 		if($::form{title} ne 'no');
 	$::form{level}=5 if($::form{level}+0 eq 0);
-
 	foreach $basepage(split(/\n/,$::database{$menubar})) {
-
 		if ($basepage=~/^(\*{1,5})(.+)/) {
 			$name=$basepage;
 			$name=~s/^(\*{1,5})//g;
 			$name=&plugin_sitemap_trim($name);
 			$menucount++;
 			push(@sitemap,$name);
-
 		}elsif($basepage=~/$::bracket_name/ && $basepage!~/>(http:|https:|ftp:|mailto:|\?)/
 			&& $basepage!~/($::interwiki_name1|$::interwiki_name2)/) {
 			$basepage=~s/$::bracket_name/$1/g;
@@ -85,7 +77,6 @@ sub plugin_sitemap_action {
 			if(&is_readable($basepage)) {
 				$submenu++;
 				$sitemap{$name}.=sprintf("%05d\t%05d\t%05d\t%05d\t%s\n",$menucount,$submenu,0,0,$basepage);
-
 				$sitemap{$name}.=&submenu($basepage,$menucount,$submenu,0,1);
 			}
 		}
@@ -139,7 +130,6 @@ sub plugin_sitemap_action {
 	}
 	return ('msg' => "\t$::resource{sitemap_plugin_title}", 'body' => $body);
 }
-
 sub submenu {
 	my($pagename,$menucount,$submenu,$nextmenu,$nest)=@_;
 	my $ret="";
@@ -156,10 +146,8 @@ sub submenu {
 			$nextmenu++;
 			$ret.=sprintf("%05d\t%05d\t%05d\t%05d\t%s\n",$menucount,$submenu,$nextmenu,$nest,$nextpage);
 			$ret.=&submenu($nextpage,$menucount,$submenu,$nextmenu+1,$nest+1);
-
 		} elsif($line=~/^#include\((.*?)\)/ && $::form{include} eq '') {
 			$ret.=&submenu((split(/,/,$1))[0],$menucount+1,$submenu,$nextmenu+1,$nest)
-
 		}elsif(($line=~/^#ls2\((.*?)\)/ || $line=~/^#ls2/) && $::form{ls2} eq '') {
 			my @ls2args = split(/,/, $1);
 			my $ls2prefix;
@@ -188,13 +176,10 @@ sub submenu {
 	}
 	return $ret;
 }
-
 sub plugin_sitemap_trim {
 	my($str,$strlen)=@_;
-
-	$Zspace = '(?:\xA1\xA1)'; # ѥڡ
+	$Zspace = '(?:\xA1\xA1)';
 	$eucpre = qr{(?<!\x8F)};
-
 	if($strlen+0 > 0) {
 		my $len=length($str);
 		$str=substr($str,0,$strlen);
@@ -203,10 +188,8 @@ sub plugin_sitemap_trim {
 		}
 		$str.="..." if($len ne length($str));
 	}
-
-
-	$str =~ s/^(?:\s|$Zspace)+//o; # $str  EUC-JP ξ
-	$str =~ s/$eucpre(?:\s|$Zspace)+$//o; # $str  EUC-JP ξ(perl5.005ʹ)
+	$str =~ s/^(?:\s|$Zspace)+//o;
+	$str =~ s/$eucpre(?:\s|$Zspace)+$//o; # $str  EUC-JP ξ(perl5.005ʹ
 	$str=~s/\~//g;
 	$str=~s/[\r|\n]//g;
 	return $str;
